# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "DataStoreType",
        "DocumentProcessingMode",
        "DataStoreConnection",
        "DataStoreConnectionSignals",
    },
)


class DataStoreType(proto.Enum):
    r"""Type of a data store.
    Determines how search is performed in the data store.

    Values:
        DATA_STORE_TYPE_UNSPECIFIED (0):
            Not specified. This value indicates that the
            data store type is not specified, so it will not
            be used during search.
        PUBLIC_WEB (1):
            A data store that contains public web
            content.
        UNSTRUCTURED (2):
            A data store that contains unstructured
            private data.
        STRUCTURED (3):
            A data store that contains structured data
            (for example FAQ).
    """
    DATA_STORE_TYPE_UNSPECIFIED = 0
    PUBLIC_WEB = 1
    UNSTRUCTURED = 2
    STRUCTURED = 3


class DocumentProcessingMode(proto.Enum):
    r"""The document processing mode of the data store.

    Values:
        DOCUMENT_PROCESSING_MODE_UNSPECIFIED (0):
            Not specified. This should be set for STRUCTURED type data
            stores. Due to legacy reasons this is considered as
            DOCUMENTS for STRUCTURED and PUBLIC_WEB data stores.
        DOCUMENTS (1):
            Documents are processed as documents.
        CHUNKS (2):
            Documents are converted to chunks.
    """
    DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0
    DOCUMENTS = 1
    CHUNKS = 2


class DataStoreConnection(proto.Message):
    r"""A data store connection. It represents a data store in
    Discovery Engine and the type of the contents it contains.

    Attributes:
        data_store_type (google.cloud.dialogflowcx_v3beta1.types.DataStoreType):
            The type of the connected data store.
        data_store (str):
            The full name of the referenced data store. Formats:
            ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}``
            ``projects/{project}/locations/{location}/dataStores/{data_store}``
        document_processing_mode (google.cloud.dialogflowcx_v3beta1.types.DocumentProcessingMode):
            The document processing mode for the data store connection.
            Should only be set for PUBLIC_WEB and UNSTRUCTURED data
            stores. If not set it is considered as DOCUMENTS, as this is
            the legacy mode.
    """

    data_store_type: "DataStoreType" = proto.Field(
        proto.ENUM,
        number=1,
        enum="DataStoreType",
    )
    data_store: str = proto.Field(
        proto.STRING,
        number=2,
    )
    document_processing_mode: "DocumentProcessingMode" = proto.Field(
        proto.ENUM,
        number=4,
        enum="DocumentProcessingMode",
    )


class DataStoreConnectionSignals(proto.Message):
    r"""Data store connection feature output signals.
    Might be only partially field if processing stop before the
    final answer. Reasons for this can be, but are not limited to:
    empty UCS search results, positive RAI check outcome, grounding
    failure, ...

    Attributes:
        rewriter_model_call_signals (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.RewriterModelCallSignals):
            Optional. Diagnostic info related to the
            rewriter model call.
        rewritten_query (str):
            Optional. Rewritten string query used for
            search.
        search_snippets (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.SearchSnippet]):
            Optional. Search snippets included in the
            answer generation prompt.
        answer_generation_model_call_signals (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.AnswerGenerationModelCallSignals):
            Optional. Diagnostic info related to the
            answer generation model call.
        answer (str):
            Optional. The final compiled answer.
        answer_parts (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.AnswerPart]):
            Optional. Answer parts with relevant citations.
            Concatenation of texts should add up the ``answer`` (not
            counting whitespaces).
        cited_snippets (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.CitedSnippet]):
            Optional. Snippets cited by the answer
            generation model from the most to least
            relevant.
        grounding_signals (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.GroundingSignals):
            Optional. Grounding signals.
        safety_signals (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.SafetySignals):
            Optional. Safety check result.
    """

    class RewriterModelCallSignals(proto.Message):
        r"""Diagnostic info related to the rewriter model call.

        Attributes:
            rendered_prompt (str):
                Prompt as sent to the model.
            model_output (str):
                Output of the generative model.
            model (str):
                Name of the generative model. For example,
                "gemini-ultra", "gemini-pro", "gemini-1.5-flash"
                etc. Defaults to "Other" if the model is
                unknown.
        """

        rendered_prompt: str = proto.Field(
            proto.STRING,
            number=1,
        )
        model_output: str = proto.Field(
            proto.STRING,
            number=2,
        )
        model: str = proto.Field(
            proto.STRING,
            number=3,
        )

    class SearchSnippet(proto.Message):
        r"""Search snippet details.

        Attributes:
            document_title (str):
                Title of the enclosing document.
            document_uri (str):
                Uri for the document. Present if specified
                for the document.
            text (str):
                Text included in the prompt.
        """

        document_title: str = proto.Field(
            proto.STRING,
            number=1,
        )
        document_uri: str = proto.Field(
            proto.STRING,
            number=2,
        )
        text: str = proto.Field(
            proto.STRING,
            number=3,
        )

    class AnswerGenerationModelCallSignals(proto.Message):
        r"""Diagnostic info related to the answer generation model call.

        Attributes:
            rendered_prompt (str):
                Prompt as sent to the model.
            model_output (str):
                Output of the generative model.
            model (str):
                Name of the generative model. For example,
                "gemini-ultra", "gemini-pro", "gemini-1.5-flash"
                etc. Defaults to "Other" if the model is
                unknown.
        """

        rendered_prompt: str = proto.Field(
            proto.STRING,
            number=1,
        )
        model_output: str = proto.Field(
            proto.STRING,
            number=2,
        )
        model: str = proto.Field(
            proto.STRING,
            number=3,
        )

    class AnswerPart(proto.Message):
        r"""Answer part with citation.

        Attributes:
            text (str):
                Substring of the answer.
            supporting_indices (MutableSequence[int]):
                Citations for this answer part. Indices of
                ``search_snippets``.
        """

        text: str = proto.Field(
            proto.STRING,
            number=1,
        )
        supporting_indices: MutableSequence[int] = proto.RepeatedField(
            proto.INT32,
            number=2,
        )

    class CitedSnippet(proto.Message):
        r"""Snippet cited by the answer generation model.

        Attributes:
            search_snippet (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.SearchSnippet):
                Details of the snippet.
            snippet_index (int):
                Index of the snippet in ``search_snippets`` field.
        """

        search_snippet: "DataStoreConnectionSignals.SearchSnippet" = proto.Field(
            proto.MESSAGE,
            number=1,
            message="DataStoreConnectionSignals.SearchSnippet",
        )
        snippet_index: int = proto.Field(
            proto.INT32,
            number=2,
        )

    class GroundingSignals(proto.Message):
        r"""Grounding signals.

        Attributes:
            decision (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.GroundingSignals.GroundingDecision):
                Represents the decision of the grounding
                check.
            score (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.GroundingSignals.GroundingScoreBucket):
                Grounding score bucket setting.
        """

        class GroundingDecision(proto.Enum):
            r"""Represents the decision of the grounding check.

            Values:
                GROUNDING_DECISION_UNSPECIFIED (0):
                    Decision not specified.
                ACCEPTED_BY_GROUNDING (1):
                    Grounding have accepted the answer.
                REJECTED_BY_GROUNDING (2):
                    Grounding have rejected the answer.
            """
            GROUNDING_DECISION_UNSPECIFIED = 0
            ACCEPTED_BY_GROUNDING = 1
            REJECTED_BY_GROUNDING = 2

        class GroundingScoreBucket(proto.Enum):
            r"""Grounding score buckets.

            Values:
                GROUNDING_SCORE_BUCKET_UNSPECIFIED (0):
                    Score not specified.
                VERY_LOW (1):
                    We have very low confidence that the answer
                    is grounded.
                LOW (3):
                    We have low confidence that the answer is
                    grounded.
                MEDIUM (4):
                    We have medium confidence that the answer is
                    grounded.
                HIGH (5):
                    We have high confidence that the answer is
                    grounded.
                VERY_HIGH (6):
                    We have very high confidence that the answer
                    is grounded.
            """
            GROUNDING_SCORE_BUCKET_UNSPECIFIED = 0
            VERY_LOW = 1
            LOW = 3
            MEDIUM = 4
            HIGH = 5
            VERY_HIGH = 6

        decision: "DataStoreConnectionSignals.GroundingSignals.GroundingDecision" = (
            proto.Field(
                proto.ENUM,
                number=1,
                enum="DataStoreConnectionSignals.GroundingSignals.GroundingDecision",
            )
        )
        score: "DataStoreConnectionSignals.GroundingSignals.GroundingScoreBucket" = (
            proto.Field(
                proto.ENUM,
                number=2,
                enum="DataStoreConnectionSignals.GroundingSignals.GroundingScoreBucket",
            )
        )

    class SafetySignals(proto.Message):
        r"""Safety check results.

        Attributes:
            decision (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.SafetySignals.SafetyDecision):
                Safety decision.
            banned_phrase_match (google.cloud.dialogflowcx_v3beta1.types.DataStoreConnectionSignals.SafetySignals.BannedPhraseMatch):
                Specifies banned phrase match subject.
            matched_banned_phrase (str):
                The matched banned phrase if there was a
                match.
        """

        class SafetyDecision(proto.Enum):
            r"""Safety decision.
            All kinds of check are incorporated into this final decision,
            including banned phrases check.

            Values:
                SAFETY_DECISION_UNSPECIFIED (0):
                    Decision not specified.
                ACCEPTED_BY_SAFETY_CHECK (1):
                    No manual or automatic safety check fired.
                REJECTED_BY_SAFETY_CHECK (2):
                    One ore more safety checks fired.
            """
            SAFETY_DECISION_UNSPECIFIED = 0
            ACCEPTED_BY_SAFETY_CHECK = 1
            REJECTED_BY_SAFETY_CHECK = 2

        class BannedPhraseMatch(proto.Enum):
            r"""Specifies banned phrase match subject.

            Values:
                BANNED_PHRASE_MATCH_UNSPECIFIED (0):
                    No banned phrase check was executed.
                BANNED_PHRASE_MATCH_NONE (1):
                    All banned phrase checks led to no match.
                BANNED_PHRASE_MATCH_QUERY (2):
                    A banned phrase matched the query.
                BANNED_PHRASE_MATCH_RESPONSE (3):
                    A banned phrase matched the response.
            """
            BANNED_PHRASE_MATCH_UNSPECIFIED = 0
            BANNED_PHRASE_MATCH_NONE = 1
            BANNED_PHRASE_MATCH_QUERY = 2
            BANNED_PHRASE_MATCH_RESPONSE = 3

        decision: "DataStoreConnectionSignals.SafetySignals.SafetyDecision" = (
            proto.Field(
                proto.ENUM,
                number=1,
                enum="DataStoreConnectionSignals.SafetySignals.SafetyDecision",
            )
        )
        banned_phrase_match: "DataStoreConnectionSignals.SafetySignals.BannedPhraseMatch" = proto.Field(
            proto.ENUM,
            number=2,
            enum="DataStoreConnectionSignals.SafetySignals.BannedPhraseMatch",
        )
        matched_banned_phrase: str = proto.Field(
            proto.STRING,
            number=3,
        )

    rewriter_model_call_signals: RewriterModelCallSignals = proto.Field(
        proto.MESSAGE,
        number=1,
        message=RewriterModelCallSignals,
    )
    rewritten_query: str = proto.Field(
        proto.STRING,
        number=2,
    )
    search_snippets: MutableSequence[SearchSnippet] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=SearchSnippet,
    )
    answer_generation_model_call_signals: AnswerGenerationModelCallSignals = (
        proto.Field(
            proto.MESSAGE,
            number=4,
            message=AnswerGenerationModelCallSignals,
        )
    )
    answer: str = proto.Field(
        proto.STRING,
        number=5,
    )
    answer_parts: MutableSequence[AnswerPart] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=AnswerPart,
    )
    cited_snippets: MutableSequence[CitedSnippet] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=CitedSnippet,
    )
    grounding_signals: GroundingSignals = proto.Field(
        proto.MESSAGE,
        number=8,
        message=GroundingSignals,
    )
    safety_signals: SafetySignals = proto.Field(
        proto.MESSAGE,
        number=9,
        message=SafetySignals,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "BigQueryExportSettings",
    },
)


class BigQueryExportSettings(proto.Message):
    r"""The settings of BigQuery export.

    Attributes:
        enabled (bool):
            The field to indicate whether the BigQuery
            export is enabled.
        bigquery_table (str):
            The BigQuery table to export. Format:
            ``projects/<ProjectID>/datasets/<DatasetID>/tables/<TableID>``.
    """

    enabled: bool = proto.Field(
        proto.BOOL,
        number=1,
    )
    bigquery_table: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import struct_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "ToolCall",
        "ToolCallResult",
    },
)


class ToolCall(proto.Message):
    r"""Represents a call of a specific tool's action with the
    specified inputs.

    Attributes:
        tool (str):
            The [tool][Tool] associated with this call. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/tools/<Tool ID>``.
        action (str):
            The name of the tool's action associated with
            this call.
        input_parameters (google.protobuf.struct_pb2.Struct):
            The action's input parameters.
    """

    tool: str = proto.Field(
        proto.STRING,
        number=1,
    )
    action: str = proto.Field(
        proto.STRING,
        number=2,
    )
    input_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=3,
        message=struct_pb2.Struct,
    )


class ToolCallResult(proto.Message):
    r"""The result of calling a tool's action that has been executed
    by the client.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        tool (str):
            The [tool][Tool] associated with this call. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/tools/<Tool ID>``.
        action (str):
            The name of the tool's action associated with
            this call.
        error (google.cloud.dialogflowcx_v3beta1.types.ToolCallResult.Error):
            The tool call's error.

            This field is a member of `oneof`_ ``result``.
        output_parameters (google.protobuf.struct_pb2.Struct):
            The tool call's output parameters.

            This field is a member of `oneof`_ ``result``.
    """

    class Error(proto.Message):
        r"""An error produced by the tool call.

        Attributes:
            message (str):
                The error message of the function.
        """

        message: str = proto.Field(
            proto.STRING,
            number=1,
        )

    tool: str = proto.Field(
        proto.STRING,
        number=1,
    )
    action: str = proto.Field(
        proto.STRING,
        number=2,
    )
    error: Error = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="result",
        message=Error,
    )
    output_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="result",
        message=struct_pb2.Struct,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.dialogflowcx_v3beta1.types import environment as gcdc_environment
from google.cloud.dialogflowcx_v3beta1.types import flow, intent, page, session

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "GetConversationRequest",
        "DeleteConversationRequest",
        "ListConversationsRequest",
        "ListConversationsResponse",
        "Conversation",
    },
)


class GetConversationRequest(proto.Message):
    r"""The request message for [Conversations.GetConversation][].

    Attributes:
        name (str):
            Required. The name of the conversation. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/conversations/<ConversationID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DeleteConversationRequest(proto.Message):
    r"""The request message for [Conversations.DeleteConversation][].

    Attributes:
        name (str):
            Required. The name of the conversation. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/conversations/<ConversationID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListConversationsRequest(proto.Message):
    r"""The request message for [Conversations.ListConversations][].

    Attributes:
        parent (str):
            Required. The agent to list all conversations for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>``.
        filter (str):
            Optional. The filter string. Supports filter by create_time,
            metrics.has_end_interaction, metrics.has_live_agent_handoff,
            intents.display_name, pages.display_name and
            flows.display_name. Timestamps expect an
            [RFC-3339][https://datatracker.ietf.org/doc/html/rfc3339]
            formatted string (e.g. 2012-04-21T11:30:00-04:00). UTC
            offsets are supported. Some examples:

            1. By create time: create_time > "2022-04-21T11:30:00-04:00"
            2. By intent display name: intents.display_name : "billing"
            3. By end interaction signal: metrics.has_end_interaction =
               true
        page_size (int):
            Optional. The maximum number of items to
            return in a single page. By default 100 and at
            most 1000.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            list request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListConversationsResponse(proto.Message):
    r"""The response message for [Conversations.ListConversations][].

    Attributes:
        conversations (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Conversation]):
            The list of conversations. There will be a maximum number of
            items returned based on the
            [page_size][google.cloud.dialogflow.cx.v3beta1.ListConversationsRequest.page_size]
            field. The returned conversations will be sorted by
            start_time in descending order (newest conversation first).
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    conversations: MutableSequence["Conversation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Conversation",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Conversation(proto.Message):
    r"""Represents a conversation.

    Attributes:
        name (str):
            Identifier. The identifier of the conversation. If
            conversation ID is reused, interactions happened later than
            48 hours of the conversation's create time will be ignored.
            Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/conversations/<ConversationID>``
        type_ (google.cloud.dialogflowcx_v3beta1.types.Conversation.Type):
            The type of the conversation.
        language_code (str):
            The language of the conversation, which is
            the language of the first request in the
            conversation.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Start time of the conversation, which is the
            time of the first request of the conversation.
        duration (google.protobuf.duration_pb2.Duration):
            Duration of the conversation.
        metrics (google.cloud.dialogflowcx_v3beta1.types.Conversation.Metrics):
            Conversation metrics.
        intents (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Intent]):
            All the matched
            [Intent][google.cloud.dialogflow.cx.v3beta1.Intent] in the
            conversation. Only ``name`` and ``display_name`` are filled
            in this message.
        flows (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Flow]):
            All the [Flow][google.cloud.dialogflow.cx.v3beta1.Flow] the
            conversation has went through. Only ``name`` and
            ``display_name`` are filled in this message.
        pages (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Page]):
            All the [Page][google.cloud.dialogflow.cx.v3beta1.Page] the
            conversation has went through. Only ``name`` and
            ``display_name`` are filled in this message.
        interactions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Conversation.Interaction]):
            Interactions of the conversation. Only populated for
            ``GetConversation`` and empty for ``ListConversations``.
        environment (google.cloud.dialogflowcx_v3beta1.types.Environment):
            Environment of the conversation. Only ``name`` and
            ``display_name`` are filled in this message.
        flow_versions (MutableMapping[str, int]):
            Flow versions used in the conversation.
    """

    class Type(proto.Enum):
        r"""Represents the type of a conversation.

        Values:
            TYPE_UNSPECIFIED (0):
                Not specified. This value should never be
                used.
            AUDIO (1):
                Audio conversation. A conversation is
                classified as an audio conversation if any
                request has STT input audio or any response has
                TTS output audio.
            TEXT (2):
                Text conversation. A conversation is
                classified as a text conversation if any request
                has text input and no request has STT input
                audio and no response has TTS output audio.
            UNDETERMINED (3):
                Default conversation type for a conversation.
                A conversation is classified as undetermined if
                none of the requests contain text or audio input
                (eg. event or intent input).
        """
        TYPE_UNSPECIFIED = 0
        AUDIO = 1
        TEXT = 2
        UNDETERMINED = 3

    class Metrics(proto.Message):
        r"""Represents metrics for the conversation.

        Attributes:
            interaction_count (int):
                The number of interactions in the
                conversation.
            input_audio_duration (google.protobuf.duration_pb2.Duration):
                Duration of all the input's audio in the
                conversation.
            output_audio_duration (google.protobuf.duration_pb2.Duration):
                Duration of all the output's audio in the
                conversation.
            max_webhook_latency (google.protobuf.duration_pb2.Duration):
                Maximum latency of the
                [Webhook][google.cloud.dialogflow.cx.v3beta1.Webhook] calls
                in the conversation.
            has_end_interaction (bool):
                A signal that indicates the interaction with the Dialogflow
                agent has ended. If any response has the
                [ResponseMessage.end_interaction][google.cloud.dialogflow.cx.v3beta1.ResponseMessage.end_interaction]
                signal, this is set to true.
            has_live_agent_handoff (bool):
                Hands off conversation to a human agent. If any response has
                the
                [ResponseMessage.live_agent_handoff][google.cloud.dialogflow.cx.v3beta1.ResponseMessage.live_agent_handoff]signal,
                this is set to true.
            average_match_confidence (float):
                The average confidence all of the
                [Match][google.cloud.dialogflow.cx.v3beta1.Match] in the
                conversation. Values range from 0.0 (completely uncertain)
                to 1.0 (completely certain).
            query_input_count (google.cloud.dialogflowcx_v3beta1.types.Conversation.Metrics.QueryInputCount):
                Query input counts.
            match_type_count (google.cloud.dialogflowcx_v3beta1.types.Conversation.Metrics.MatchTypeCount):
                Match type counts.
        """

        class QueryInputCount(proto.Message):
            r"""Count by types of
            [QueryInput][google.cloud.dialogflow.cx.v3beta1.QueryInput] of the
            requests in the conversation.

            Attributes:
                text_count (int):
                    The number of
                    [TextInput][google.cloud.dialogflow.cx.v3beta1.TextInput] in
                    the conversation.
                intent_count (int):
                    The number of
                    [IntentInput][google.cloud.dialogflow.cx.v3beta1.IntentInput]
                    in the conversation.
                audio_count (int):
                    The number of
                    [AudioInput][google.cloud.dialogflow.cx.v3beta1.AudioInput]
                    in the conversation.
                event_count (int):
                    The number of
                    [EventInput][google.cloud.dialogflow.cx.v3beta1.EventInput]
                    in the conversation.
                dtmf_count (int):
                    The number of
                    [DtmfInput][google.cloud.dialogflow.cx.v3beta1.DtmfInput] in
                    the conversation.
            """

            text_count: int = proto.Field(
                proto.INT32,
                number=1,
            )
            intent_count: int = proto.Field(
                proto.INT32,
                number=2,
            )
            audio_count: int = proto.Field(
                proto.INT32,
                number=3,
            )
            event_count: int = proto.Field(
                proto.INT32,
                number=4,
            )
            dtmf_count: int = proto.Field(
                proto.INT32,
                number=5,
            )

        class MatchTypeCount(proto.Message):
            r"""Count by
            [Match.MatchType][google.cloud.dialogflow.cx.v3beta1.Match.MatchType]
            of the matches in the conversation.

            Attributes:
                unspecified_count (int):
                    The number of matches with type
                    [Match.MatchType.MATCH_TYPE_UNSPECIFIED][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.MATCH_TYPE_UNSPECIFIED].
                intent_count (int):
                    The number of matches with type
                    [Match.MatchType.INTENT][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.INTENT].
                direct_intent_count (int):
                    The number of matches with type
                    [Match.MatchType.DIRECT_INTENT][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.DIRECT_INTENT].
                parameter_filling_count (int):
                    The number of matches with type
                    [Match.MatchType.PARAMETER_FILLING][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.PARAMETER_FILLING].
                no_match_count (int):
                    The number of matches with type
                    [Match.MatchType.NO_MATCH][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.NO_MATCH].
                no_input_count (int):
                    The number of matches with type
                    [Match.MatchType.NO_INPUT][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.NO_INPUT].
                event_count (int):
                    The number of matches with type
                    [Match.MatchType.EVENT][google.cloud.dialogflow.cx.v3beta1.Match.MatchType.EVENT].
            """

            unspecified_count: int = proto.Field(
                proto.INT32,
                number=1,
            )
            intent_count: int = proto.Field(
                proto.INT32,
                number=2,
            )
            direct_intent_count: int = proto.Field(
                proto.INT32,
                number=3,
            )
            parameter_filling_count: int = proto.Field(
                proto.INT32,
                number=4,
            )
            no_match_count: int = proto.Field(
                proto.INT32,
                number=5,
            )
            no_input_count: int = proto.Field(
                proto.INT32,
                number=6,
            )
            event_count: int = proto.Field(
                proto.INT32,
                number=7,
            )

        interaction_count: int = proto.Field(
            proto.INT32,
            number=1,
        )
        input_audio_duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=2,
            message=duration_pb2.Duration,
        )
        output_audio_duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=3,
            message=duration_pb2.Duration,
        )
        max_webhook_latency: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=4,
            message=duration_pb2.Duration,
        )
        has_end_interaction: bool = proto.Field(
            proto.BOOL,
            number=5,
        )
        has_live_agent_handoff: bool = proto.Field(
            proto.BOOL,
            number=6,
        )
        average_match_confidence: float = proto.Field(
            proto.FLOAT,
            number=7,
        )
        query_input_count: "Conversation.Metrics.QueryInputCount" = proto.Field(
            proto.MESSAGE,
            number=8,
            message="Conversation.Metrics.QueryInputCount",
        )
        match_type_count: "Conversation.Metrics.MatchTypeCount" = proto.Field(
            proto.MESSAGE,
            number=9,
            message="Conversation.Metrics.MatchTypeCount",
        )

    class Interaction(proto.Message):
        r"""Represents an interaction between an end user and a
        Dialogflow CX agent using V3 (Streaming)DetectIntent API, or an
        interaction between an end user and a Dialogflow CX agent using
        V2 (Streaming)AnalyzeContent API.

        Attributes:
            request (google.cloud.dialogflowcx_v3beta1.types.DetectIntentRequest):
                The request of the interaction.
            response (google.cloud.dialogflowcx_v3beta1.types.DetectIntentResponse):
                The final response of the interaction.
            partial_responses (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.DetectIntentResponse]):
                The partial responses of the interaction. Empty if there is
                no partial response in the interaction. See the [partial
                response
                documentation][https://cloud.google.com/dialogflow/cx/docs/concept/fulfillment#queue].
            request_utterances (str):
                The input text or the transcript of the input
                audio in the request.
            response_utterances (str):
                The output text or the transcript of the
                output audio in the responses. If multiple
                output messages are returned, they will be
                concatenated into one.
            create_time (google.protobuf.timestamp_pb2.Timestamp):
                The time that the interaction was created.
            answer_feedback (google.cloud.dialogflowcx_v3beta1.types.AnswerFeedback):
                Answer feedback for the final response.
            missing_transition (google.cloud.dialogflowcx_v3beta1.types.Conversation.Interaction.MissingTransition):
                Missing transition predicted for the
                interaction. This field is set only if the
                interaction match type was no-match.
            step_metrics (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Conversation.Interaction.StepMetrics]):
                Metrics associated with different processing
                steps. Names and number of steps depend on the
                request and can change without a notice.
        """

        class MissingTransition(proto.Message):
            r"""Information collected for DF CX agents in case NLU predicted
            an intent that was filtered out as being inactive which may
            indicate a missing transition and/or absent functionality.

            Attributes:
                intent_display_name (str):
                    Name of the intent that could have triggered.
                score (float):
                    Score of the above intent. The higher it is
                    the more likely a transition was missed on a
                    given page.
            """

            intent_display_name: str = proto.Field(
                proto.STRING,
                number=1,
            )
            score: float = proto.Field(
                proto.FLOAT,
                number=2,
            )

        class StepMetrics(proto.Message):
            r"""Metrics of each processing step.

            Attributes:
                name (str):
                    Name of the request processing step.
                latency (google.protobuf.duration_pb2.Duration):
                    Processing latency of the step.
            """

            name: str = proto.Field(
                proto.STRING,
                number=1,
            )
            latency: duration_pb2.Duration = proto.Field(
                proto.MESSAGE,
                number=2,
                message=duration_pb2.Duration,
            )

        request: session.DetectIntentRequest = proto.Field(
            proto.MESSAGE,
            number=1,
            message=session.DetectIntentRequest,
        )
        response: session.DetectIntentResponse = proto.Field(
            proto.MESSAGE,
            number=2,
            message=session.DetectIntentResponse,
        )
        partial_responses: MutableSequence[
            session.DetectIntentResponse
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=3,
            message=session.DetectIntentResponse,
        )
        request_utterances: str = proto.Field(
            proto.STRING,
            number=4,
        )
        response_utterances: str = proto.Field(
            proto.STRING,
            number=5,
        )
        create_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=6,
            message=timestamp_pb2.Timestamp,
        )
        answer_feedback: session.AnswerFeedback = proto.Field(
            proto.MESSAGE,
            number=7,
            message=session.AnswerFeedback,
        )
        missing_transition: "Conversation.Interaction.MissingTransition" = proto.Field(
            proto.MESSAGE,
            number=8,
            message="Conversation.Interaction.MissingTransition",
        )
        step_metrics: MutableSequence[
            "Conversation.Interaction.StepMetrics"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=9,
            message="Conversation.Interaction.StepMetrics",
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=2,
        enum=Type,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=3,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=5,
        message=duration_pb2.Duration,
    )
    metrics: Metrics = proto.Field(
        proto.MESSAGE,
        number=6,
        message=Metrics,
    )
    intents: MutableSequence[intent.Intent] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=intent.Intent,
    )
    flows: MutableSequence[flow.Flow] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message=flow.Flow,
    )
    pages: MutableSequence[page.Page] = proto.RepeatedField(
        proto.MESSAGE,
        number=9,
        message=page.Page,
    )
    interactions: MutableSequence[Interaction] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message=Interaction,
    )
    environment: gcdc_environment.Environment = proto.Field(
        proto.MESSAGE,
        number=11,
        message=gcdc_environment.Environment,
    )
    flow_versions: MutableMapping[str, int] = proto.MapField(
        proto.STRING,
        proto.INT64,
        number=12,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.dialogflowcx_v3beta1.types import data_store_connection, inline

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "CreateToolRequest",
        "ListToolsRequest",
        "ListToolsResponse",
        "GetToolRequest",
        "ExportToolsRequest",
        "ExportToolsResponse",
        "UpdateToolRequest",
        "DeleteToolRequest",
        "Tool",
        "ListToolVersionsRequest",
        "ListToolVersionsResponse",
        "CreateToolVersionRequest",
        "GetToolVersionRequest",
        "DeleteToolVersionRequest",
        "RestoreToolVersionRequest",
        "RestoreToolVersionResponse",
        "ToolVersion",
        "ExportToolsMetadata",
    },
)


class CreateToolRequest(proto.Message):
    r"""The request message for
    [Tools.CreateTool][google.cloud.dialogflow.cx.v3beta1.Tools.CreateTool].

    Attributes:
        parent (str):
            Required. The agent to create a Tool for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>``.
        tool (google.cloud.dialogflowcx_v3beta1.types.Tool):
            Required. The Tool to be created.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    tool: "Tool" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Tool",
    )


class ListToolsRequest(proto.Message):
    r"""The request message for
    [Tools.ListTools][google.cloud.dialogflow.cx.v3beta1.Tools.ListTools].

    Attributes:
        parent (str):
            Required. The agent to list the Tools from. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>``.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 100 and at most 1000.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListToolsResponse(proto.Message):
    r"""The response message for
    [Tools.ListTools][google.cloud.dialogflow.cx.v3beta1.Tools.ListTools].

    Attributes:
        tools (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Tool]):
            The list of Tools. There will be a maximum number of items
            returned based on the page_size field in the request.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    tools: MutableSequence["Tool"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Tool",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetToolRequest(proto.Message):
    r"""The request message for
    [Tools.GetTool][google.cloud.dialogflow.cx.v3beta1.Tools.GetTool].

    Attributes:
        name (str):
            Required. The name of the Tool. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ExportToolsRequest(proto.Message):
    r"""The request message for
    [Tools.ExportTools][google.cloud.dialogflow.cx.v3beta1.Tools.ExportTools].

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent (str):
            Required. The agent to export tools from. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>``.
        tools (MutableSequence[str]):
            Required. The name of the tools to export. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
        tools_uri (str):
            Optional. The `Google Cloud
            Storage <https://cloud.google.com/storage/docs/>`__ URI to
            export the tools to. The format of this URI must be
            ``gs://<bucket-name>/<object-name>``.

            Dialogflow performs a write operation for the Cloud Storage
            object on the caller's behalf, so your request
            authentication must have write permissions for the object.
            For more information, see `Dialogflow access
            control <https://cloud.google.com/dialogflow/cx/docs/concept/access-control#storage>`__.

            This field is a member of `oneof`_ ``destination``.
        tools_content_inline (bool):
            Optional. The option to return the serialized
            tools inline.

            This field is a member of `oneof`_ ``destination``.
        data_format (google.cloud.dialogflowcx_v3beta1.types.ExportToolsRequest.DataFormat):
            Optional. The data format of the exported tools. If not
            specified, ``BLOB`` is assumed.
    """

    class DataFormat(proto.Enum):
        r"""Data format of the exported tools.

        Values:
            DATA_FORMAT_UNSPECIFIED (0):
                Unspecified format. Treated as ``BLOB``.
            BLOB (1):
                Tools will be exported as raw bytes.
            JSON (2):
                Tools will be exported in JSON format.
        """
        DATA_FORMAT_UNSPECIFIED = 0
        BLOB = 1
        JSON = 2

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    tools: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    tools_uri: str = proto.Field(
        proto.STRING,
        number=3,
        oneof="destination",
    )
    tools_content_inline: bool = proto.Field(
        proto.BOOL,
        number=4,
        oneof="destination",
    )
    data_format: DataFormat = proto.Field(
        proto.ENUM,
        number=5,
        enum=DataFormat,
    )


class ExportToolsResponse(proto.Message):
    r"""The response message for
    [Tools.ExportTools][google.cloud.dialogflow.cx.v3beta1.Tools.ExportTools].

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        tools_uri (str):
            The URI to a file containing the exported tools. This field
            is populated only if ``tools_uri`` is specified in
            [ExportToolsRequest][google.cloud.dialogflow.cx.v3beta1.ExportToolsRequest].

            This field is a member of `oneof`_ ``tools``.
        tools_content (google.cloud.dialogflowcx_v3beta1.types.InlineDestination):
            Uncompressed byte content for tools. This field is populated
            only if ``tools_content_inline`` is set to true in
            [ExportToolsRequest][google.cloud.dialogflow.cx.v3beta1.ExportToolsRequest].

            This field is a member of `oneof`_ ``tools``.
    """

    tools_uri: str = proto.Field(
        proto.STRING,
        number=1,
        oneof="tools",
    )
    tools_content: inline.InlineDestination = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="tools",
        message=inline.InlineDestination,
    )


class UpdateToolRequest(proto.Message):
    r"""The request message for
    [Tools.UpdateTool][google.cloud.dialogflow.cx.v3beta1.Tools.UpdateTool].

    Attributes:
        tool (google.cloud.dialogflowcx_v3beta1.types.Tool):
            Required. The Tool to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The mask to control which fields get updated.
            If the mask is not present, all fields will be
            updated.
    """

    tool: "Tool" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Tool",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteToolRequest(proto.Message):
    r"""The request message for
    [Tools.DeleteTool][google.cloud.dialogflow.cx.v3beta1.Tools.DeleteTool].

    Attributes:
        name (str):
            Required. The name of the Tool to be deleted. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
        force (bool):
            This field has no effect for Tools not being used. For Tools
            that are used:

            -  If ``force`` is set to false, an error will be returned
               with message indicating the referenced resources.
            -  If ``force`` is set to true, Dialogflow will remove the
               tool, as well as any references to the tool.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class Tool(proto.Message):
    r"""A tool provides a list of actions which are available to the
    [Playbook][google.cloud.dialogflow.cx.v3beta1.Playbook] to attain
    its goal. A Tool consists of a description of the tool's usage and a
    specification of the tool which contains the schema and
    authentication information.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            The unique identifier of the Tool. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
        display_name (str):
            Required. The human-readable name of the
            Tool, unique within an agent.
        description (str):
            Required. High level description of the Tool
            and its usage.
        open_api_spec (google.cloud.dialogflowcx_v3beta1.types.Tool.OpenApiTool):
            OpenAPI specification of the Tool.

            This field is a member of `oneof`_ ``specification``.
        data_store_spec (google.cloud.dialogflowcx_v3beta1.types.Tool.DataStoreTool):
            Data store search tool specification.

            This field is a member of `oneof`_ ``specification``.
        extension_spec (google.cloud.dialogflowcx_v3beta1.types.Tool.ExtensionTool):
            Vertex extension tool specification.

            This field is a member of `oneof`_ ``specification``.
        function_spec (google.cloud.dialogflowcx_v3beta1.types.Tool.FunctionTool):
            Client side executed function specification.

            This field is a member of `oneof`_ ``specification``.
        connector_spec (google.cloud.dialogflowcx_v3beta1.types.Tool.ConnectorTool):
            Integration connectors tool specification.

            This field is a member of `oneof`_ ``specification``.
        tool_type (google.cloud.dialogflowcx_v3beta1.types.Tool.ToolType):
            Output only. The tool type.
    """

    class ToolType(proto.Enum):
        r"""Represents the type of the tool.

        Values:
            TOOL_TYPE_UNSPECIFIED (0):
                Default value. This value is unused.
            CUSTOMIZED_TOOL (1):
                Customer provided tool.
            BUILTIN_TOOL (2):
                First party built-in tool created by
                Dialogflow which cannot be modified.
        """
        TOOL_TYPE_UNSPECIFIED = 0
        CUSTOMIZED_TOOL = 1
        BUILTIN_TOOL = 2

    class OpenApiTool(proto.Message):
        r"""An OpenAPI tool is a way to provide the Tool specifications
        in the Open API schema format.


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            text_schema (str):
                Required. The OpenAPI schema specified as a
                text.

                This field is a member of `oneof`_ ``schema``.
            authentication (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication):
                Optional. Authentication information required
                by the API.
            tls_config (google.cloud.dialogflowcx_v3beta1.types.Tool.TLSConfig):
                Optional. TLS configuration for the HTTPS
                verification.
            service_directory_config (google.cloud.dialogflowcx_v3beta1.types.Tool.ServiceDirectoryConfig):
                Optional. Service Directory configuration.
        """

        text_schema: str = proto.Field(
            proto.STRING,
            number=1,
            oneof="schema",
        )
        authentication: "Tool.Authentication" = proto.Field(
            proto.MESSAGE,
            number=2,
            message="Tool.Authentication",
        )
        tls_config: "Tool.TLSConfig" = proto.Field(
            proto.MESSAGE,
            number=3,
            message="Tool.TLSConfig",
        )
        service_directory_config: "Tool.ServiceDirectoryConfig" = proto.Field(
            proto.MESSAGE,
            number=4,
            message="Tool.ServiceDirectoryConfig",
        )

    class DataStoreTool(proto.Message):
        r"""A DataStoreTool is a way to provide specifications needed to
        search a list of data stores.

        Attributes:
            data_store_connections (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.DataStoreConnection]):
                Required. List of data stores to search.
            fallback_prompt (google.cloud.dialogflowcx_v3beta1.types.Tool.DataStoreTool.FallbackPrompt):
                Required. Fallback prompt configurations to
                use.
        """

        class FallbackPrompt(proto.Message):
            r"""A FallbackPrompt is a way to provide specifications for the
            Data Store fallback prompt when generating responses.

            """

        data_store_connections: MutableSequence[
            data_store_connection.DataStoreConnection
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=data_store_connection.DataStoreConnection,
        )
        fallback_prompt: "Tool.DataStoreTool.FallbackPrompt" = proto.Field(
            proto.MESSAGE,
            number=3,
            message="Tool.DataStoreTool.FallbackPrompt",
        )

    class ExtensionTool(proto.Message):
        r"""An ExtensionTool is a way to use Vertex Extensions as a tool.

        Attributes:
            name (str):
                Required. The full name of the referenced vertex extension.
                Formats:
                ``projects/{project}/locations/{location}/extensions/{extension}``
        """

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )

    class FunctionTool(proto.Message):
        r"""A Function tool describes the functions to be invoked on the
        client side.

        Attributes:
            input_schema (google.protobuf.struct_pb2.Struct):
                Optional. The JSON schema is encapsulated in a
                [google.protobuf.Struct][google.protobuf.Struct] to describe
                the input of the function. This input is a JSON object that
                contains the function's parameters as properties of the
                object.
            output_schema (google.protobuf.struct_pb2.Struct):
                Optional. The JSON schema is encapsulated in a
                [google.protobuf.Struct][google.protobuf.Struct] to describe
                the output of the function. This output is a JSON object
                that contains the function's parameters as properties of the
                object.
        """

        input_schema: struct_pb2.Struct = proto.Field(
            proto.MESSAGE,
            number=1,
            message=struct_pb2.Struct,
        )
        output_schema: struct_pb2.Struct = proto.Field(
            proto.MESSAGE,
            number=2,
            message=struct_pb2.Struct,
        )

    class ConnectorTool(proto.Message):
        r"""A ConnectorTool enabling using Integration Connectors
        Connections as tools.

        Attributes:
            name (str):
                Required. The full resource name of the referenced
                Integration Connectors Connection. Format:
                ``projects/*/locations/*/connections/*``
            actions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Tool.ConnectorTool.Action]):
                Required. Actions for the tool to use.
            end_user_auth_config (google.cloud.dialogflowcx_v3beta1.types.Tool.EndUserAuthConfig):
                Optional. Integration Connectors end-user authentication
                configuration. If configured, the end-user authentication
                fields will be passed in the Integration Connectors API
                request and override the admin, default authentication
                configured for the Connection. **Note**: The Connection must
                have authentication override enabled in order to specify an
                EUC configuration here - otherwise, the ConnectorTool
                creation will fail. See:
                https://cloud.google.com/application-integration/docs/configure-connectors-task#configure-authentication-override
        """

        class Action(proto.Message):
            r"""Configuration of a Connection operation for the tool to use.

            This message has `oneof`_ fields (mutually exclusive fields).
            For each oneof, at most one member field can be set at the same time.
            Setting any member of the oneof automatically clears all other
            members.

            .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

            Attributes:
                connection_action_id (str):
                    ID of a Connection action for the tool to
                    use.

                    This field is a member of `oneof`_ ``action_spec``.
                entity_operation (google.cloud.dialogflowcx_v3beta1.types.Tool.ConnectorTool.Action.EntityOperation):
                    Entity operation configuration for the tool
                    to use.

                    This field is a member of `oneof`_ ``action_spec``.
                input_fields (MutableSequence[str]):
                    Optional. Entity fields to use as inputs for
                    the operation. If no fields are specified, all
                    fields of the Entity will be used.
                output_fields (MutableSequence[str]):
                    Optional. Entity fields to return from the
                    operation. If no fields are specified, all
                    fields of the Entity will be returned.
            """

            class EntityOperation(proto.Message):
                r"""Entity CRUD operation specification.

                Attributes:
                    entity_id (str):
                        Required. ID of the entity.
                    operation (google.cloud.dialogflowcx_v3beta1.types.Tool.ConnectorTool.Action.EntityOperation.OperationType):
                        Required. Operation to perform on the entity.
                """

                class OperationType(proto.Enum):
                    r"""The operation to perform on the entity.

                    Values:
                        OPERATION_TYPE_UNSPECIFIED (0):
                            Operation type unspecified. Invalid,
                            ConnectorTool create/update will fail.
                        LIST (1):
                            List operation.
                        GET (2):
                            Get operation.
                        CREATE (3):
                            Create operation.
                        UPDATE (4):
                            Update operation.
                        DELETE (5):
                            Delete operation.
                    """
                    OPERATION_TYPE_UNSPECIFIED = 0
                    LIST = 1
                    GET = 2
                    CREATE = 3
                    UPDATE = 4
                    DELETE = 5

                entity_id: str = proto.Field(
                    proto.STRING,
                    number=1,
                )
                operation: "Tool.ConnectorTool.Action.EntityOperation.OperationType" = (
                    proto.Field(
                        proto.ENUM,
                        number=2,
                        enum="Tool.ConnectorTool.Action.EntityOperation.OperationType",
                    )
                )

            connection_action_id: str = proto.Field(
                proto.STRING,
                number=4,
                oneof="action_spec",
            )
            entity_operation: "Tool.ConnectorTool.Action.EntityOperation" = proto.Field(
                proto.MESSAGE,
                number=5,
                oneof="action_spec",
                message="Tool.ConnectorTool.Action.EntityOperation",
            )
            input_fields: MutableSequence[str] = proto.RepeatedField(
                proto.STRING,
                number=2,
            )
            output_fields: MutableSequence[str] = proto.RepeatedField(
                proto.STRING,
                number=3,
            )

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        actions: MutableSequence["Tool.ConnectorTool.Action"] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="Tool.ConnectorTool.Action",
        )
        end_user_auth_config: "Tool.EndUserAuthConfig" = proto.Field(
            proto.MESSAGE,
            number=3,
            message="Tool.EndUserAuthConfig",
        )

    class Authentication(proto.Message):
        r"""Authentication information required for API calls

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            api_key_config (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.ApiKeyConfig):
                Config for API key auth.

                This field is a member of `oneof`_ ``auth_config``.
            oauth_config (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.OAuthConfig):
                Config for OAuth.

                This field is a member of `oneof`_ ``auth_config``.
            service_agent_auth_config (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.ServiceAgentAuthConfig):
                Config for `Diglogflow service
                agent <https://cloud.google.com/iam/docs/service-agents#dialogflow-service-agent>`__
                auth.

                This field is a member of `oneof`_ ``auth_config``.
            bearer_token_config (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.BearerTokenConfig):
                Config for bearer token auth.

                This field is a member of `oneof`_ ``auth_config``.
        """

        class RequestLocation(proto.Enum):
            r"""The location of the API key in the request.

            Values:
                REQUEST_LOCATION_UNSPECIFIED (0):
                    Default value. This value is unused.
                HEADER (1):
                    Represents the key in http header.
                QUERY_STRING (2):
                    Represents the key in query string.
            """
            REQUEST_LOCATION_UNSPECIFIED = 0
            HEADER = 1
            QUERY_STRING = 2

        class ApiKeyConfig(proto.Message):
            r"""Config for authentication with API key.

            Attributes:
                key_name (str):
                    Required. The parameter name or the header
                    name of the API key. E.g., If the API request is
                    "https://example.com/act?X-Api-Key=<API KEY>",
                    "X-Api-Key" would be the parameter name.
                api_key (str):
                    Optional. The API key. If the ``secret_version_for_api_key``
                    field is set, this field will be ignored.
                request_location (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.RequestLocation):
                    Required. Key location in the request.
            """

            key_name: str = proto.Field(
                proto.STRING,
                number=1,
            )
            api_key: str = proto.Field(
                proto.STRING,
                number=2,
            )
            request_location: "Tool.Authentication.RequestLocation" = proto.Field(
                proto.ENUM,
                number=3,
                enum="Tool.Authentication.RequestLocation",
            )

        class OAuthConfig(proto.Message):
            r"""Config for authentication with OAuth.

            Attributes:
                oauth_grant_type (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.OAuthConfig.OauthGrantType):
                    Required. OAuth grant types.
                client_id (str):
                    Required. The client ID from the OAuth
                    provider.
                client_secret (str):
                    Optional. The client secret from the OAuth provider. If the
                    ``secret_version_for_client_secret`` field is set, this
                    field will be ignored.
                token_endpoint (str):
                    Required. The token endpoint in the OAuth
                    provider to exchange for an access token.
                scopes (MutableSequence[str]):
                    Optional. The OAuth scopes to grant.
            """

            class OauthGrantType(proto.Enum):
                r"""OAuth grant types. Only `client credential
                grant <https://oauth.net/2/grant-types/client-credentials>`__ is
                supported.

                Values:
                    OAUTH_GRANT_TYPE_UNSPECIFIED (0):
                        Default value. This value is unused.
                    CLIENT_CREDENTIAL (1):
                        Represents the `client credential
                        flow <https://oauth.net/2/grant-types/client-credentials>`__.
                """
                OAUTH_GRANT_TYPE_UNSPECIFIED = 0
                CLIENT_CREDENTIAL = 1

            oauth_grant_type: "Tool.Authentication.OAuthConfig.OauthGrantType" = (
                proto.Field(
                    proto.ENUM,
                    number=1,
                    enum="Tool.Authentication.OAuthConfig.OauthGrantType",
                )
            )
            client_id: str = proto.Field(
                proto.STRING,
                number=2,
            )
            client_secret: str = proto.Field(
                proto.STRING,
                number=3,
            )
            token_endpoint: str = proto.Field(
                proto.STRING,
                number=4,
            )
            scopes: MutableSequence[str] = proto.RepeatedField(
                proto.STRING,
                number=5,
            )

        class ServiceAgentAuthConfig(proto.Message):
            r"""Config for auth using `Diglogflow service
            agent <https://cloud.google.com/iam/docs/service-agents#dialogflow-service-agent>`__.

            Attributes:
                service_agent_auth (google.cloud.dialogflowcx_v3beta1.types.Tool.Authentication.ServiceAgentAuthConfig.ServiceAgentAuth):
                    Optional. Indicate the auth token type generated from the
                    `Diglogflow service
                    agent <https://cloud.google.com/iam/docs/service-agents#dialogflow-service-agent>`__.
                    The generated token is sent in the Authorization header.
            """

            class ServiceAgentAuth(proto.Enum):
                r"""Indicate the auth token type generated from the `Diglogflow service
                agent <https://cloud.google.com/iam/docs/service-agents#dialogflow-service-agent>`__.

                Values:
                    SERVICE_AGENT_AUTH_UNSPECIFIED (0):
                        Service agent auth type unspecified. Default to ID_TOKEN.
                    ID_TOKEN (1):
                        Use `ID
                        token <https://cloud.google.com/docs/authentication/token-types#id>`__
                        generated from service agent. This can be used to access
                        Cloud Function and Cloud Run after you grant Invoker role to
                        ``service-<PROJECT-NUMBER>@gcp-sa-dialogflow.iam.gserviceaccount.com``.
                    ACCESS_TOKEN (2):
                        Use `access
                        token <https://cloud.google.com/docs/authentication/token-types#access>`__
                        generated from service agent. This can be used to access
                        other Google Cloud APIs after you grant required roles to
                        ``service-<PROJECT-NUMBER>@gcp-sa-dialogflow.iam.gserviceaccount.com``.
                """
                SERVICE_AGENT_AUTH_UNSPECIFIED = 0
                ID_TOKEN = 1
                ACCESS_TOKEN = 2

            service_agent_auth: "Tool.Authentication.ServiceAgentAuthConfig.ServiceAgentAuth" = proto.Field(
                proto.ENUM,
                number=1,
                enum="Tool.Authentication.ServiceAgentAuthConfig.ServiceAgentAuth",
            )

        class BearerTokenConfig(proto.Message):
            r"""Config for authentication using bearer token.

            Attributes:
                token (str):
                    Optional. The text token appended to the text ``Bearer`` to
                    the request Authorization header. `Session parameters
                    reference <https://cloud.google.com/dialogflow/cx/docs/concept/parameter#session-ref>`__
                    can be used to pass the token dynamically, e.g.
                    ``$session.params.parameter-id``.
            """

            token: str = proto.Field(
                proto.STRING,
                number=1,
            )

        api_key_config: "Tool.Authentication.ApiKeyConfig" = proto.Field(
            proto.MESSAGE,
            number=1,
            oneof="auth_config",
            message="Tool.Authentication.ApiKeyConfig",
        )
        oauth_config: "Tool.Authentication.OAuthConfig" = proto.Field(
            proto.MESSAGE,
            number=2,
            oneof="auth_config",
            message="Tool.Authentication.OAuthConfig",
        )
        service_agent_auth_config: "Tool.Authentication.ServiceAgentAuthConfig" = (
            proto.Field(
                proto.MESSAGE,
                number=3,
                oneof="auth_config",
                message="Tool.Authentication.ServiceAgentAuthConfig",
            )
        )
        bearer_token_config: "Tool.Authentication.BearerTokenConfig" = proto.Field(
            proto.MESSAGE,
            number=4,
            oneof="auth_config",
            message="Tool.Authentication.BearerTokenConfig",
        )

    class TLSConfig(proto.Message):
        r"""The TLS configuration.

        Attributes:
            ca_certs (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Tool.TLSConfig.CACert]):
                Required. Specifies a list of allowed custom
                CA certificates for HTTPS verification.
        """

        class CACert(proto.Message):
            r"""The CA certificate.

            Attributes:
                display_name (str):
                    Required. The name of the allowed custom CA
                    certificates. This can be used to disambiguate
                    the custom CA certificates.
                cert (bytes):
                    Required. The allowed custom CA certificates (in DER format)
                    for HTTPS verification. This overrides the default SSL trust
                    store. If this is empty or unspecified, Dialogflow will use
                    Google's default trust store to verify certificates. N.B.
                    Make sure the HTTPS server certificates are signed with
                    "subject alt name". For instance a certificate can be
                    self-signed using the following command:

                    ::

                          openssl x509 -req -days 200 -in example.com.csr \
                            -signkey example.com.key \
                            -out example.com.crt \
                            -extfile <(printf "\nsubjectAltName='DNS:www.example.com'")
            """

            display_name: str = proto.Field(
                proto.STRING,
                number=1,
            )
            cert: bytes = proto.Field(
                proto.BYTES,
                number=2,
            )

        ca_certs: MutableSequence["Tool.TLSConfig.CACert"] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message="Tool.TLSConfig.CACert",
        )

    class ServiceDirectoryConfig(proto.Message):
        r"""Configuration for tools using Service Directory.

        Attributes:
            service (str):
                Required. The name of `Service
                Directory <https://cloud.google.com/service-directory>`__
                service. Format:
                ``projects/<ProjectID>/locations/<LocationID>/namespaces/<NamespaceID>/services/<ServiceID>``.
                ``LocationID`` of the service directory must be the same as
                the location of the agent.
        """

        service: str = proto.Field(
            proto.STRING,
            number=1,
        )

    class EndUserAuthConfig(proto.Message):
        r"""End-user authentication configuration used for Connection calls. The
        field values can either be hardcoded authentication values or the
        names of `session
        parameters <https://cloud.google.com/dialogflow/cx/docs/concept/parameter#session-ref>`__
        or `request
        parameters <https://cloud.google.com/dialogflow/cx/docs/concept/parameter#request-scoped>`__.

        If parameter names are provided, then those parameters can be used
        to pass the authentication values dynamically, through
        ``$session.params.param-id`` or ``$request.payload.param-id``.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            oauth2_auth_code_config (google.cloud.dialogflowcx_v3beta1.types.Tool.EndUserAuthConfig.Oauth2AuthCodeConfig):
                Oauth 2.0 Authorization Code authentication.

                This field is a member of `oneof`_ ``end_user_auth_config``.
            oauth2_jwt_bearer_config (google.cloud.dialogflowcx_v3beta1.types.Tool.EndUserAuthConfig.Oauth2JwtBearerConfig):
                JWT Profile Oauth 2.0 Authorization Grant
                authentication.

                This field is a member of `oneof`_ ``end_user_auth_config``.
        """

        class Oauth2AuthCodeConfig(proto.Message):
            r"""Oauth 2.0 Authorization Code authentication configuration.

            Attributes:
                oauth_token (str):
                    Required. Oauth token value or parameter name
                    to pass it through.
            """

            oauth_token: str = proto.Field(
                proto.STRING,
                number=1,
            )

        class Oauth2JwtBearerConfig(proto.Message):
            r"""JWT Profile Oauth 2.0 Authorization Grant authentication
            configuration.

            Attributes:
                issuer (str):
                    Required. Issuer value or parameter name to
                    pass it through.
                subject (str):
                    Required. Subject value or parameter name to
                    pass it through.
                client_key (str):
                    Required. Client key value or parameter name
                    to pass it through.
            """

            issuer: str = proto.Field(
                proto.STRING,
                number=1,
            )
            subject: str = proto.Field(
                proto.STRING,
                number=2,
            )
            client_key: str = proto.Field(
                proto.STRING,
                number=3,
            )

        oauth2_auth_code_config: "Tool.EndUserAuthConfig.Oauth2AuthCodeConfig" = (
            proto.Field(
                proto.MESSAGE,
                number=2,
                oneof="end_user_auth_config",
                message="Tool.EndUserAuthConfig.Oauth2AuthCodeConfig",
            )
        )
        oauth2_jwt_bearer_config: "Tool.EndUserAuthConfig.Oauth2JwtBearerConfig" = (
            proto.Field(
                proto.MESSAGE,
                number=3,
                oneof="end_user_auth_config",
                message="Tool.EndUserAuthConfig.Oauth2JwtBearerConfig",
            )
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    open_api_spec: OpenApiTool = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="specification",
        message=OpenApiTool,
    )
    data_store_spec: DataStoreTool = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="specification",
        message=DataStoreTool,
    )
    extension_spec: ExtensionTool = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof="specification",
        message=ExtensionTool,
    )
    function_spec: FunctionTool = proto.Field(
        proto.MESSAGE,
        number=13,
        oneof="specification",
        message=FunctionTool,
    )
    connector_spec: ConnectorTool = proto.Field(
        proto.MESSAGE,
        number=15,
        oneof="specification",
        message=ConnectorTool,
    )
    tool_type: ToolType = proto.Field(
        proto.ENUM,
        number=12,
        enum=ToolType,
    )


class ListToolVersionsRequest(proto.Message):
    r"""The request message for
    [Tools.ListToolVersions][google.cloud.dialogflow.cx.v3beta1.Tools.ListToolVersions].

    Attributes:
        parent (str):
            Required. The parent of the tool versions. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
        page_size (int):
            Optional. The maximum number of items to
            return in a single page. By default 100 and at
            most 1000.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            list request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListToolVersionsResponse(proto.Message):
    r"""The response message for
    [Tools.ListToolVersions][google.cloud.dialogflow.cx.v3beta1.Tools.ListToolVersions].

    Attributes:
        tool_versions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.ToolVersion]):
            The list of tool versions. There will be a maximum number of
            items returned based on the page_size field in the request.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    tool_versions: MutableSequence["ToolVersion"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="ToolVersion",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateToolVersionRequest(proto.Message):
    r"""The request message for
    [Tools.CreateToolVersion][google.cloud.dialogflow.cx.v3beta1.Tools.CreateToolVersion].
    The request message for
    [Tools.CreateToolVersion][google.cloud.dialogflow.cx.v3beta1.Tools.CreateToolVersion].

    Attributes:
        parent (str):
            Required. The tool to create a version for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
        tool_version (google.cloud.dialogflowcx_v3beta1.types.ToolVersion):
            Required. The tool version to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    tool_version: "ToolVersion" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="ToolVersion",
    )


class GetToolVersionRequest(proto.Message):
    r"""The request message for
    [Tools.GetToolVersion][google.cloud.dialogflow.cx.v3beta1.Tools.GetToolVersion].

    Attributes:
        name (str):
            Required. The name of the tool version. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DeleteToolVersionRequest(proto.Message):
    r"""The request message for
    [Tools.DeleteToolVersion][google.cloud.dialogflow.cx.v3beta1.Tools.DeleteToolVersion].

    Attributes:
        name (str):
            Required. The name of the tool version to delete. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>``.
        force (bool):
            Optional. This field has no effect for Tools not being used.
            For Tools that are used:

            -  If ``force`` is set to false, an error will be returned
               with message indicating the referenced resources.
            -  If ``force`` is set to true, Dialogflow will remove the
               tool, as well as any references to the tool.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class RestoreToolVersionRequest(proto.Message):
    r"""The request message for
    [Tools.RestoreToolVersion][google.cloud.dialogflow.cx.v3beta1.Tools.RestoreToolVersion].

    Attributes:
        name (str):
            Required. The name of the tool version. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class RestoreToolVersionResponse(proto.Message):
    r"""The response message for
    [Tools.RestoreToolVersion][google.cloud.dialogflow.cx.v3beta1.Tools.RestoreToolVersion].

    Attributes:
        tool (google.cloud.dialogflowcx_v3beta1.types.Tool):
            The updated tool.
    """

    tool: "Tool" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Tool",
    )


class ToolVersion(proto.Message):
    r"""Tool version is a snapshot of the tool at certain timestamp.

    Attributes:
        name (str):
            Identifier. The unique identifier of the tool version.
            Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>/versions/<VersionID>``.
        display_name (str):
            Required. The display name of the tool
            version.
        tool (google.cloud.dialogflowcx_v3beta1.types.Tool):
            Required. Snapshot of the tool to be
            associated with this version.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last time the tool version was
            created or modified.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last time the tool version was
            created or modified.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    tool: "Tool" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Tool",
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )


class ExportToolsMetadata(proto.Message):
    r"""Metadata returned for the
    [Tools.ExportTools][google.cloud.dialogflow.cx.v3beta1.Tools.ExportTools]
    long running operation.

    """


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "ParameterDefinition",
    },
)


class ParameterDefinition(proto.Message):
    r"""Defines the properties of a parameter.
    Used to define parameters used in the agent and the input /
    output parameters for each fulfillment.
    (-- Next Id: 4 --)
    (-- api-linter: core::0123::resource-annotation=disabled
    aip.dev/not-precedent: ParameterDefinition is not an exposed
    resource.     --)

    Attributes:
        name (str):
            Name of parameter.
        type_ (google.cloud.dialogflowcx_v3beta1.types.ParameterDefinition.ParameterType):
            Type of parameter.
        description (str):
            Human-readable description of the parameter.
            Limited to 300 characters.
    """

    class ParameterType(proto.Enum):
        r"""Parameter types are used for validation. These types are consistent
        with [google.protobuf.Value][].

        Values:
            PARAMETER_TYPE_UNSPECIFIED (0):
                Not specified. No validation will be
                performed.
            STRING (1):
                Represents any string value.
            NUMBER (2):
                Represents any number value.
            BOOLEAN (3):
                Represents a boolean value.
            NULL (4):
                Represents a null value.
            OBJECT (5):
                Represents any object value.
            LIST (6):
                Represents a repeated value.
        """
        PARAMETER_TYPE_UNSPECIFIED = 0
        STRING = 1
        NUMBER = 2
        BOOLEAN = 3
        NULL = 4
        OBJECT = 5
        LIST = 6

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    type_: ParameterType = proto.Field(
        proto.ENUM,
        number=2,
        enum=ParameterType,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "OutputState",
        "CreateExampleRequest",
        "DeleteExampleRequest",
        "ListExamplesRequest",
        "ListExamplesResponse",
        "GetExampleRequest",
        "UpdateExampleRequest",
        "Example",
        "PlaybookInput",
        "PlaybookOutput",
        "Action",
        "UserUtterance",
        "AgentUtterance",
        "ToolUse",
        "PlaybookInvocation",
        "FlowInvocation",
    },
)


class OutputState(proto.Enum):
    r"""Output state.

    Values:
        OUTPUT_STATE_UNSPECIFIED (0):
            Unspecified output.
        OUTPUT_STATE_OK (1):
            Succeeded.
        OUTPUT_STATE_CANCELLED (2):
            Cancelled.
        OUTPUT_STATE_FAILED (3):
            Failed.
        OUTPUT_STATE_ESCALATED (4):
            Escalated.
        OUTPUT_STATE_PENDING (5):
            Pending.
    """
    OUTPUT_STATE_UNSPECIFIED = 0
    OUTPUT_STATE_OK = 1
    OUTPUT_STATE_CANCELLED = 2
    OUTPUT_STATE_FAILED = 3
    OUTPUT_STATE_ESCALATED = 4
    OUTPUT_STATE_PENDING = 5


class CreateExampleRequest(proto.Message):
    r"""The request message for
    [Examples.CreateExample][google.cloud.dialogflow.cx.v3beta1.Examples.CreateExample].

    Attributes:
        parent (str):
            Required. The playbook to create an example for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
        example (google.cloud.dialogflowcx_v3beta1.types.Example):
            Required. The example to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    example: "Example" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Example",
    )


class DeleteExampleRequest(proto.Message):
    r"""The request message for
    [Examples.DeleteExample][google.cloud.dialogflow.cx.v3beta1.Examples.DeleteExample].

    Attributes:
        name (str):
            Required. The name of the example to delete. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/examples/<ExampleID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListExamplesRequest(proto.Message):
    r"""The request message for
    [Examples.ListExamples][google.cloud.dialogflow.cx.v3beta1.Examples.ListExamples].

    Attributes:
        parent (str):
            Required. The playbook to list the examples from. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
        page_size (int):
            Optional. The maximum number of items to
            return in a single page. By default 100 and at
            most 1000.
        page_token (str):
            Optional. The
            [next_page_token][ListExampleResponse.next_page_token] value
            returned from a previous list request.
        language_code (str):
            Optional. The language to list examples for.
            If not specified, list all examples under the
            playbook. Note: languages must be enabled in the
            agent before they can be used.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListExamplesResponse(proto.Message):
    r"""The response message for
    [Examples.ListExamples][google.cloud.dialogflow.cx.v3beta1.Examples.ListExamples].

    Attributes:
        examples (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Example]):
            The list of examples. There will be a maximum number of
            items returned based on the
            [page_size][google.cloud.dialogflow.cx.v3beta1.ListExamplesRequest.page_size]
            field in the request.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    examples: MutableSequence["Example"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Example",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetExampleRequest(proto.Message):
    r"""The request message for
    [Examples.GetExample][google.cloud.dialogflow.cx.v3beta1.Examples.GetExample].

    Attributes:
        name (str):
            Required. The name of the example. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/examples/<ExampleID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateExampleRequest(proto.Message):
    r"""The request message for
    [Examples.UpdateExample][google.cloud.dialogflow.cx.v3beta1.Examples.UpdateExample].

    Attributes:
        example (google.cloud.dialogflowcx_v3beta1.types.Example):
            Required. The example to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Optional. The mask to control which fields
            get updated. If the mask is not present, all
            fields will be updated.
    """

    example: "Example" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Example",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class Example(proto.Message):
    r"""Example represents a sample execution of the playbook in the
    conversation.
    An example consists of a list of ordered actions performed by
    end user or Dialogflow agent according the playbook instructions
    to fulfill the task.

    Attributes:
        name (str):
            The unique identifier of the playbook example. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/examples/<ExampleID>``.
        playbook_input (google.cloud.dialogflowcx_v3beta1.types.PlaybookInput):
            Optional. The input to the playbook in the
            example.
        playbook_output (google.cloud.dialogflowcx_v3beta1.types.PlaybookOutput):
            Optional. The output of the playbook in the
            example.
        actions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Action]):
            Required. The ordered list of actions
            performed by the end user and the Dialogflow
            agent.
        display_name (str):
            Required. The display name of the example.
        description (str):
            Optional. The high level concise description
            of the example. The max number of characters is
            200.
        token_count (int):
            Output only. Estimated number of tokes
            current example takes when sent to the LLM.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp of initial example
            creation.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last time the example was
            updated.
        conversation_state (google.cloud.dialogflowcx_v3beta1.types.OutputState):
            Required. Example's output state.
        language_code (str):
            Optional. The language code of the example.
            If not specified, the agent's default language
            is used. Note: languages must be enabled in the
            agent before they can be used. Note: example's
            language code is not currently used in
            dialogflow agents.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    playbook_input: "PlaybookInput" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="PlaybookInput",
    )
    playbook_output: "PlaybookOutput" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="PlaybookOutput",
    )
    actions: MutableSequence["Action"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="Action",
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=6,
    )
    description: str = proto.Field(
        proto.STRING,
        number=8,
    )
    token_count: int = proto.Field(
        proto.INT64,
        number=9,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=10,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=11,
        message=timestamp_pb2.Timestamp,
    )
    conversation_state: "OutputState" = proto.Field(
        proto.ENUM,
        number=12,
        enum="OutputState",
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=13,
    )


class PlaybookInput(proto.Message):
    r"""Input of the playbook.

    Attributes:
        preceding_conversation_summary (str):
            Optional. Summary string of the preceding
            conversation for the child playbook invocation.
        action_parameters (google.protobuf.struct_pb2.Struct):
            Optional. A list of input parameters for the
            action.
    """

    preceding_conversation_summary: str = proto.Field(
        proto.STRING,
        number=1,
    )
    action_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=3,
        message=struct_pb2.Struct,
    )


class PlaybookOutput(proto.Message):
    r"""Output of the playbook.

    Attributes:
        execution_summary (str):
            Optional. Summary string of the execution
            result of the child playbook.
        action_parameters (google.protobuf.struct_pb2.Struct):
            Optional. A Struct object of output
            parameters for the action.
    """

    execution_summary: str = proto.Field(
        proto.STRING,
        number=1,
    )
    action_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=4,
        message=struct_pb2.Struct,
    )


class Action(proto.Message):
    r"""Action performed by end user or Dialogflow agent in the
    conversation.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_utterance (google.cloud.dialogflowcx_v3beta1.types.UserUtterance):
            Optional. Agent obtained a message from the
            customer.

            This field is a member of `oneof`_ ``action``.
        agent_utterance (google.cloud.dialogflowcx_v3beta1.types.AgentUtterance):
            Optional. Action performed by the agent as a
            message.

            This field is a member of `oneof`_ ``action``.
        tool_use (google.cloud.dialogflowcx_v3beta1.types.ToolUse):
            Optional. Action performed on behalf of the
            agent by calling a plugin tool.

            This field is a member of `oneof`_ ``action``.
        playbook_invocation (google.cloud.dialogflowcx_v3beta1.types.PlaybookInvocation):
            Optional. Action performed on behalf of the
            agent by invoking a child playbook.

            This field is a member of `oneof`_ ``action``.
        flow_invocation (google.cloud.dialogflowcx_v3beta1.types.FlowInvocation):
            Optional. Action performed on behalf of the
            agent by invoking a CX flow.

            This field is a member of `oneof`_ ``action``.
    """

    user_utterance: "UserUtterance" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="action",
        message="UserUtterance",
    )
    agent_utterance: "AgentUtterance" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="action",
        message="AgentUtterance",
    )
    tool_use: "ToolUse" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="action",
        message="ToolUse",
    )
    playbook_invocation: "PlaybookInvocation" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="action",
        message="PlaybookInvocation",
    )
    flow_invocation: "FlowInvocation" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="action",
        message="FlowInvocation",
    )


class UserUtterance(proto.Message):
    r"""UserUtterance represents one message sent by the customer.

    Attributes:
        text (str):
            Required. Message content in text.
    """

    text: str = proto.Field(
        proto.STRING,
        number=1,
    )


class AgentUtterance(proto.Message):
    r"""AgentUtterance represents one message sent by the agent.

    Attributes:
        text (str):
            Required. Message content in text.
    """

    text: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ToolUse(proto.Message):
    r"""Stores metadata of the invocation of an action supported by a
    tool.

    Attributes:
        tool (str):
            Required. The
            [tool][google.cloud.dialogflow.cx.v3beta1.Tool] that should
            be used. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/tools/<ToolID>``.
        display_name (str):
            Output only. The display name of the tool.
        action (str):
            Optional. Name of the action to be called
            during the tool use.
        input_action_parameters (google.protobuf.struct_pb2.Struct):
            Optional. A list of input parameters for the
            action.
        output_action_parameters (google.protobuf.struct_pb2.Struct):
            Optional. A list of output parameters
            generated by the action.
    """

    tool: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=8,
    )
    action: str = proto.Field(
        proto.STRING,
        number=2,
    )
    input_action_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=5,
        message=struct_pb2.Struct,
    )
    output_action_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=6,
        message=struct_pb2.Struct,
    )


class PlaybookInvocation(proto.Message):
    r"""Stores metadata of the invocation of a child playbook.

    Attributes:
        playbook (str):
            Required. The unique identifier of the playbook. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
        display_name (str):
            Output only. The display name of the
            playbook.
        playbook_input (google.cloud.dialogflowcx_v3beta1.types.PlaybookInput):
            Optional. Input of the child playbook
            invocation.
        playbook_output (google.cloud.dialogflowcx_v3beta1.types.PlaybookOutput):
            Optional. Output of the child playbook
            invocation.
        playbook_state (google.cloud.dialogflowcx_v3beta1.types.OutputState):
            Required. Playbook invocation's output state.
    """

    playbook: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=5,
    )
    playbook_input: "PlaybookInput" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="PlaybookInput",
    )
    playbook_output: "PlaybookOutput" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="PlaybookOutput",
    )
    playbook_state: "OutputState" = proto.Field(
        proto.ENUM,
        number=4,
        enum="OutputState",
    )


class FlowInvocation(proto.Message):
    r"""Stores metadata of the invocation of a CX flow.

    Attributes:
        flow (str):
            Required. The unique identifier of the flow. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/flows/<FlowID>``.
        display_name (str):
            Output only. The display name of the flow.
        input_action_parameters (google.protobuf.struct_pb2.Struct):
            Optional. A list of input parameters for the
            flow.
        output_action_parameters (google.protobuf.struct_pb2.Struct):
            Optional. A list of output parameters
            generated by the flow invocation.
        flow_state (google.cloud.dialogflowcx_v3beta1.types.OutputState):
            Required. Flow invocation's output state.
    """

    flow: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=7,
    )
    input_action_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=5,
        message=struct_pb2.Struct,
    )
    output_action_parameters: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=6,
        message=struct_pb2.Struct,
    )
    flow_state: "OutputState" = proto.Field(
        proto.ENUM,
        number=4,
        enum="OutputState",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.dialogflowcx_v3beta1.types import (
    generative_settings,
    parameter_definition,
)
from google.cloud.dialogflowcx_v3beta1.types import fulfillment as gcdc_fulfillment
from google.cloud.dialogflowcx_v3beta1.types import advanced_settings, example

__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "CreatePlaybookRequest",
        "DeletePlaybookRequest",
        "ListPlaybooksRequest",
        "ListPlaybooksResponse",
        "GetPlaybookRequest",
        "UpdatePlaybookRequest",
        "Playbook",
        "CreatePlaybookVersionRequest",
        "PlaybookVersion",
        "GetPlaybookVersionRequest",
        "ListPlaybookVersionsRequest",
        "ListPlaybookVersionsResponse",
        "DeletePlaybookVersionRequest",
        "Handler",
    },
)


class CreatePlaybookRequest(proto.Message):
    r"""The request message for
    [Playbooks.CreatePlaybook][google.cloud.dialogflow.cx.v3beta1.Playbooks.CreatePlaybook].

    Attributes:
        parent (str):
            Required. The agent to create a playbook for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>``.
        playbook (google.cloud.dialogflowcx_v3beta1.types.Playbook):
            Required. The playbook to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    playbook: "Playbook" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Playbook",
    )


class DeletePlaybookRequest(proto.Message):
    r"""The request message for
    [Playbooks.DeletePlaybook][google.cloud.dialogflow.cx.v3beta1.Playbooks.DeletePlaybook].

    Attributes:
        name (str):
            Required. The name of the playbook to delete. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListPlaybooksRequest(proto.Message):
    r"""The request message for
    [Playbooks.ListPlaybooks][google.cloud.dialogflow.cx.v3beta1.Playbooks.ListPlaybooks].

    Attributes:
        parent (str):
            Required. The agent to list playbooks from. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>``.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 100 and at most 1000.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListPlaybooksResponse(proto.Message):
    r"""The response message for
    [Playbooks.ListPlaybooks][google.cloud.dialogflow.cx.v3beta1.Playbooks.ListPlaybooks].

    Attributes:
        playbooks (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Playbook]):
            The list of playbooks. There will be a maximum number of
            items returned based on the page_size field in the request.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    playbooks: MutableSequence["Playbook"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Playbook",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetPlaybookRequest(proto.Message):
    r"""The request message for
    [Playbooks.GetPlaybook][google.cloud.dialogflow.cx.v3beta1.Playbooks.GetPlaybook].

    Attributes:
        name (str):
            Required. The name of the playbook. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdatePlaybookRequest(proto.Message):
    r"""The request message for
    [Playbooks.UpdatePlaybook][google.cloud.dialogflow.cx.v3beta1.Playbooks.UpdatePlaybook].

    Attributes:
        playbook (google.cloud.dialogflowcx_v3beta1.types.Playbook):
            Required. The playbook to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The mask to control which fields get updated.
            If the mask is not present, all fields will be
            updated.
    """

    playbook: "Playbook" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Playbook",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class Playbook(proto.Message):
    r"""Playbook is the basic building block to instruct the LLM how
    to execute a certain task.

    A playbook consists of a goal to accomplish, an optional list of
    step by step instructions (the step instruction may refers to
    name of the custom or default plugin tools to use) to perform
    the task,
    a list of contextual input data to be passed in at the beginning
    of the invoked, and a list of output parameters to store the
    playbook result.

    Attributes:
        name (str):
            The unique identifier of the playbook. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
        display_name (str):
            Required. The human-readable name of the
            playbook, unique within an agent.
        goal (str):
            Required. High level description of the goal
            the playbook intend to accomplish. A goal should
            be concise since it's visible to other playbooks
            that may reference this playbook.
        input_parameter_definitions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.ParameterDefinition]):
            Optional. Defined structured input parameters
            for this playbook.
        output_parameter_definitions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.ParameterDefinition]):
            Optional. Defined structured output
            parameters for this playbook.
        instruction (google.cloud.dialogflowcx_v3beta1.types.Playbook.Instruction):
            Instruction to accomplish target goal.
        token_count (int):
            Output only. Estimated number of tokes
            current playbook takes when sent to the LLM.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp of initial
            playbook creation.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last time the playbook version
            was updated.
        referenced_playbooks (MutableSequence[str]):
            Output only. The resource name of other
            playbooks referenced by the current playbook in
            the instructions.
        referenced_flows (MutableSequence[str]):
            Output only. The resource name of flows
            referenced by the current playbook in the
            instructions.
        referenced_tools (MutableSequence[str]):
            Optional. The resource name of tools
            referenced by the current playbook in the
            instructions. If not provided explicitly, they
            are will be implied using the tool being
            referenced in goal and steps.
        llm_model_settings (google.cloud.dialogflowcx_v3beta1.types.LlmModelSettings):
            Optional. Llm model settings for the
            playbook.
        speech_settings (google.cloud.dialogflowcx_v3beta1.types.AdvancedSettings.SpeechSettings):
            Optional. Playbook level Settings for speech
            to text detection.
        handlers (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Handler]):
            Optional. A list of registered handlers to
            execute based on the specified triggers.
    """

    class Step(proto.Message):
        r"""Message of single step execution.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            text (str):
                Step instruction in text format.

                This field is a member of `oneof`_ ``instruction``.
            steps (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Playbook.Step]):
                Sub-processing needed to execute the current
                step.
        """

        text: str = proto.Field(
            proto.STRING,
            number=1,
            oneof="instruction",
        )
        steps: MutableSequence["Playbook.Step"] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="Playbook.Step",
        )

    class Instruction(proto.Message):
        r"""Message of the Instruction of the playbook.

        Attributes:
            guidelines (str):
                General guidelines for the playbook. These
                are unstructured instructions that are not
                directly part of the goal, e.g. "Always be
                polite". It's valid for this text to be long and
                used instead of steps altogether.
            steps (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Playbook.Step]):
                Ordered list of step by step execution
                instructions to accomplish target goal.
        """

        guidelines: str = proto.Field(
            proto.STRING,
            number=1,
        )
        steps: MutableSequence["Playbook.Step"] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="Playbook.Step",
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    goal: str = proto.Field(
        proto.STRING,
        number=3,
    )
    input_parameter_definitions: MutableSequence[
        parameter_definition.ParameterDefinition
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=parameter_definition.ParameterDefinition,
    )
    output_parameter_definitions: MutableSequence[
        parameter_definition.ParameterDefinition
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=parameter_definition.ParameterDefinition,
    )
    instruction: Instruction = proto.Field(
        proto.MESSAGE,
        number=17,
        message=Instruction,
    )
    token_count: int = proto.Field(
        proto.INT64,
        number=8,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=9,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=10,
        message=timestamp_pb2.Timestamp,
    )
    referenced_playbooks: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=11,
    )
    referenced_flows: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=12,
    )
    referenced_tools: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=13,
    )
    llm_model_settings: generative_settings.LlmModelSettings = proto.Field(
        proto.MESSAGE,
        number=14,
        message=generative_settings.LlmModelSettings,
    )
    speech_settings: advanced_settings.AdvancedSettings.SpeechSettings = proto.Field(
        proto.MESSAGE,
        number=20,
        message=advanced_settings.AdvancedSettings.SpeechSettings,
    )
    handlers: MutableSequence["Handler"] = proto.RepeatedField(
        proto.MESSAGE,
        number=16,
        message="Handler",
    )


class CreatePlaybookVersionRequest(proto.Message):
    r"""The request message for
    [Playbooks.CreatePlaybookVersion][google.cloud.dialogflow.cx.v3beta1.Playbooks.CreatePlaybookVersion].

    Attributes:
        parent (str):
            Required. The playbook to create a version for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
        playbook_version (google.cloud.dialogflowcx_v3beta1.types.PlaybookVersion):
            Required. The playbook version to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    playbook_version: "PlaybookVersion" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="PlaybookVersion",
    )


class PlaybookVersion(proto.Message):
    r"""Playbook version is a snapshot of the playbook at certain
    timestamp.

    Attributes:
        name (str):
            The unique identifier of the playbook version. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>``.
        description (str):
            Optional. The description of the playbook
            version.
        playbook (google.cloud.dialogflowcx_v3beta1.types.Playbook):
            Output only. Snapshot of the playbook when
            the playbook version is created.
        examples (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.Example]):
            Output only. Snapshot of the examples
            belonging to the playbook when the playbook
            version is created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last time the playbook version
            was created or modified.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    playbook: "Playbook" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Playbook",
    )
    examples: MutableSequence[example.Example] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=example.Example,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )


class GetPlaybookVersionRequest(proto.Message):
    r"""The request message for
    [Playbooks.GetPlaybookVersion][google.cloud.dialogflow.cx.v3beta1.Playbooks.GetPlaybookVersion].

    Attributes:
        name (str):
            Required. The name of the playbook version. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListPlaybookVersionsRequest(proto.Message):
    r"""The request message for
    [Playbooks.ListPlaybookVersions][google.cloud.dialogflow.cx.v3beta1.Playbooks.ListPlaybookVersions].

    Attributes:
        parent (str):
            Required. The playbook to list versions for. Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>``.
        page_size (int):
            Optional. The maximum number of items to
            return in a single page. By default 100 and at
            most 1000.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            list request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListPlaybookVersionsResponse(proto.Message):
    r"""The response message for
    [Playbooks.ListPlaybookVersions][google.cloud.dialogflow.cx.v3beta1.Playbooks.ListPlaybookVersions].

    Attributes:
        playbook_versions (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.PlaybookVersion]):
            The list of playbook version. There will be a maximum number
            of items returned based on the page_size field in the
            request.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    playbook_versions: MutableSequence["PlaybookVersion"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="PlaybookVersion",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeletePlaybookVersionRequest(proto.Message):
    r"""The request message for
    [Playbooks.DeletePlaybookVersion][google.cloud.dialogflow.cx.v3beta1.Playbooks.DeletePlaybookVersion].

    Attributes:
        name (str):
            Required. The name of the playbook version to delete.
            Format:
            ``projects/<ProjectID>/locations/<LocationID>/agents/<AgentID>/playbooks/<PlaybookID>/versions/<VersionID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class Handler(proto.Message):
    r"""Handler can be used to define custom logic to be executed
    based on the user-specified triggers.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        event_handler (google.cloud.dialogflowcx_v3beta1.types.Handler.EventHandler):
            A handler triggered by event.

            This field is a member of `oneof`_ ``handler``.
        lifecycle_handler (google.cloud.dialogflowcx_v3beta1.types.Handler.LifecycleHandler):
            A handler triggered during specific lifecycle
            of the playbook execution.

            This field is a member of `oneof`_ ``handler``.
    """

    class EventHandler(proto.Message):
        r"""A handler that is triggered by the specified
        [event][google.cloud.dialogflow.cx.v3beta1.Handler.EventHandler.event].

        Attributes:
            event (str):
                Required. The name of the event that triggers
                this handler.
            condition (str):
                Optional. The condition that must be
                satisfied to trigger this handler.
            fulfillment (google.cloud.dialogflowcx_v3beta1.types.Fulfillment):
                Required. The fulfillment to call when the
                event occurs.
        """

        event: str = proto.Field(
            proto.STRING,
            number=1,
        )
        condition: str = proto.Field(
            proto.STRING,
            number=3,
        )
        fulfillment: gcdc_fulfillment.Fulfillment = proto.Field(
            proto.MESSAGE,
            number=2,
            message=gcdc_fulfillment.Fulfillment,
        )

    class LifecycleHandler(proto.Message):
        r"""A handler that is triggered on the specific
        [lifecycle_stage][google.cloud.dialogflow.cx.v3beta1.Handler.LifecycleHandler.lifecycle_stage]
        of the playbook execution.

        Attributes:
            lifecycle_stage (str):
                Required. The name of the lifecycle stage that triggers this
                handler. Supported values:

                -  ``playbook-start``
                -  ``pre-action-selection``
                -  ``pre-action-execution``
            condition (str):
                Optional. The condition that must be
                satisfied to trigger this handler.
            fulfillment (google.cloud.dialogflowcx_v3beta1.types.Fulfillment):
                Required. The fulfillment to call when this
                handler is triggered.
        """

        lifecycle_stage: str = proto.Field(
            proto.STRING,
            number=1,
        )
        condition: str = proto.Field(
            proto.STRING,
            number=2,
        )
        fulfillment: gcdc_fulfillment.Fulfillment = proto.Field(
            proto.MESSAGE,
            number=3,
            message=gcdc_fulfillment.Fulfillment,
        )

    event_handler: EventHandler = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="handler",
        message=EventHandler,
    )
    lifecycle_handler: LifecycleHandler = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="handler",
        message=LifecycleHandler,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
